# Load R scripts containing the functions needed to run 1a_fetch_metals.
source("src/1_data_download.R")
source("src/1_get_wqp_col_types.R")

p1_metals_targets <- list(

  # Set the WQP data download parameters for `huc` (the hydrologic unit codes to spatially constrain the download)
  tar_target(hucs, c("0204","0713","0712","1401","1402")),

  # Set the WQP data download parameters for `characteristicName`
  tar_target(metals, c("Aluminum", "Arsenic", "Cadmium", "Chromium", "Copper", "Iron",
                     "Mercury", "Manganese", "Lead", "Selenium", "Uranium", "Zinc")),

  # Set the WQP data download parameters for `sampleMedia`
  tar_target(sampleMedia, c("Water", "water")),

  # Download the WQP data per huc and metal combination and save as separate CSVs
  tar_target(
    p1_wqp_data_huc_metal_csv,{
      fetch_date <- '2022-08-08' #change date to rerun pipeline
      download_wqp_site_data(
        huc = hucs,
        metal = metals,
        sampleMedia = sampleMedia,
        file_out = sprintf("tmp_metals/wqp_data_%s_%s.csv", hucs, metals))
      },
    pattern = cross(hucs, metals),
    format = "file"
  ),

  # Combine the individual HUC/metal CSVs from the previous step into a
  # single CSV file for all metals and hucs
  tar_target(
    p1_all_metals_data_csv,{
      file_out <- "out/all_metals_data.csv"
      purrr::map(p1_wqp_data_huc_metal_csv,
                 function(x) read_csv(x, col_types = paste(rep('c', 65), collapse = "")))%>%
        bind_rows()%>%
        write_csv(file_out)
      return(file_out)
    },
    format = "file"
  ),

  # Identify all of the unique sites (using the WQP column `MonitoringLocationIdentifier`) that
  # returned discrete metals data from our data download
  tar_target(
    site_id,{
      wqp_data<- readr::read_csv(p1_all_metals_data_csv)
      unique(wqp_data$MonitoringLocationIdentifier)
    }
  ),

  # Download the metadata for each site that returned metals data and save as a CSV
  tar_target(
    p1_site_info_all_huc_metal_csv,{
      download_site_info(
        site_id = site_id,
        file_out = ("out/site_info_all_metals.csv"))
    },
    format = "file"
  ),

  # Create a crosswalk to map the 4-digit HUCs to a human-friendly basin abbreviation
  # This is used in `1b_fetch_ancillary.R` and in `2_summarize.R`
  tar_target(basin_xwalk, tibble(hucs = hucs,
                                 basin = c("DRB", "ILRB", "ILRB", "UCOL", "UCOL")))
)

