#' @title Set the column types for reading in WQP output
#' @description Use this function for setting column types of WQP data so that
#' each dataset is read in with the same column types and can be easily combined.
#' @return an object to be passed to `readr::read_csv()` as input to `col_types`

get_wqp_col_types <- function() {
  cols(
    OrganizationIdentifier = col_character(),
    OrganizationFormalName = col_character(),
    ActivityIdentifier = col_character(),
    ActivityTypeCode = col_character(),
    ActivityMediaName = col_character(),
    ActivityMediaSubdivisionName = col_character(),
    ActivityStartDate = col_date(format = ""),
    ActivityStartTime.Time = col_time(format = ""),
    ActivityStartTime.TimeZoneCode = col_character(),
    ActivityEndDate = col_logical(),
    ActivityEndTime.Time = col_logical(),
    ActivityEndTime.TimeZoneCode = col_logical(),
    ActivityDepthHeightMeasure.MeasureValue = col_double(),
    ActivityDepthHeightMeasure.MeasureUnitCode = col_character(),
    ActivityDepthAltitudeReferencePointText = col_logical(),
    ActivityTopDepthHeightMeasure.MeasureValue = col_logical(),
    ActivityTopDepthHeightMeasure.MeasureUnitCode = col_logical(),
    ActivityBottomDepthHeightMeasure.MeasureValue = col_logical(),
    ActivityBottomDepthHeightMeasure.MeasureUnitCode = col_logical(),
    ProjectIdentifier = col_character(),
    ActivityConductingOrganizationText = col_character(),
    MonitoringLocationIdentifier = col_character(),
    ActivityCommentText = col_character(),
    SampleAquifer = col_logical(),
    HydrologicCondition = col_character(),
    HydrologicEvent = col_character(),
    SampleCollectionMethod.MethodIdentifier = col_character(),
    SampleCollectionMethod.MethodIdentifierContext = col_character(),
    SampleCollectionMethod.MethodName = col_character(),
    SampleCollectionEquipmentName = col_character(),
    ResultDetectionConditionText = col_logical(),
    CharacteristicName = col_character(),
    ResultSampleFractionText = col_character(),
    ResultMeasureValue = col_double(),
    ResultMeasure.MeasureUnitCode = col_character(),
    MeasureQualifierCode = col_logical(),
    ResultStatusIdentifier = col_character(),
    StatisticalBaseCode = col_logical(),
    ResultValueTypeName = col_character(),
    ResultWeightBasisText = col_logical(),
    ResultTimeBasisText = col_logical(),
    ResultTemperatureBasisText = col_logical(),
    ResultParticleSizeBasisText = col_logical(),
    PrecisionValue = col_logical(),
    ResultCommentText = col_character(),
    USGSPCode = col_character(),
    ResultDepthHeightMeasure.MeasureValue = col_logical(),
    ResultDepthHeightMeasure.MeasureUnitCode = col_logical(),
    ResultDepthAltitudeReferencePointText = col_logical(),
    SubjectTaxonomicName = col_logical(),
    SampleTissueAnatomyName = col_logical(),
    ResultAnalyticalMethod.MethodIdentifier = col_character(),
    ResultAnalyticalMethod.MethodIdentifierContext = col_character(),
    ResultAnalyticalMethod.MethodName = col_character(),
    MethodDescriptionText = col_character(),
    LaboratoryName = col_character(),
    AnalysisStartDate = col_logical(),
    ResultLaboratoryCommentText = col_character(),
    DetectionQuantitationLimitTypeName = col_character(),
    DetectionQuantitationLimitMeasure.MeasureValue = col_double(),
    DetectionQuantitationLimitMeasure.MeasureUnitCode = col_character(),
    PreparationStartDate = col_logical(),
    ProviderName = col_character(),
    ActivityStartDateTime = col_datetime(format = ""),
    ActivityEndDateTime = col_logical()
  )
}
